temporal.common


priority-optionsclj

ValueDescriptionTypeDefault
:priority-keyAn integer from 1 to the server-configured maximum (default 5). Smaller priority key values run sooner.int3
:fairness-keyAn identifier for the fairness balancing mechanism.String or keyword
:fairness-weightThe proportion to use for the round robin fairness balancing mechanism.float1
| Value                     | Description                                                                                             | Type              | Default |
| ------------------------- | ------------------------------------------------------------------------------------------------------- | ------------      | ------- |
| :priority-key             | An integer from 1 to the server-configured maximum (default 5). Smaller priority key values run sooner. | int               | 3       |
| :fairness-key             | An identifier for the fairness balancing mechanism.                                                     | String or keyword |         |
| :fairness-weight          | The proportion to use for the round robin fairness balancing mechanism.                                 | float             | 1       |
sourceraw docstring

retry-optionsclj

ValueDescriptionTypeDefault
:initial-intervalInterval of the first retry.Duration
:backoff-coefficientCoefficient used to calculate the next retry interval.double0.0
:maximum-attemptsWhen exceeded the amount of attempts, stop.int0 (unlimited)
:maximum-intervalMaximum interval between retries.Duration
:do-not-retryList of application failures types to not retry.list of strings[]
| Value                     | Description                                                                 | Type            | Default |
| ------------------------- | --------------------------------------------------------------------------- | ------------    | ------- |
| :initial-interval         | Interval of the first retry.                                                | [Duration](https://docs.oracle.com/javase/8/docs/api//java/time/Duration.html) | |
| :backoff-coefficient      | Coefficient used to calculate the next retry interval.                      | double          | 0.0     |
| :maximum-attempts         | When exceeded the amount of attempts, stop.                                 | int             | 0 (unlimited) |
| :maximum-interval         | Maximum interval between retries.                                           | [Duration](https://docs.oracle.com/javase/8/docs/api//java/time/Duration.html) | |
| :do-not-retry             | List of application failures types to not retry.                            | list of strings | []      |
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries